#!/usr/bin/env python3
import os
from subprocess import check_output
import re
from time import sleep

#
#  Feel free (a.k.a. you have to) to modify this to instrument your code
#

THREADS = [0]
LOOPS = [1, 10]
INPUTS = ["seq_64_test.txt"]

csvs = []
for inp in INPUTS:
    for loop in LOOPS:
        csv = ["{}/{}".format(inp, loop)]
        for thr in THREADS:
            cmd = "./bin/prefix_scan -o temp.txt -n {} -i tests/{} -l {}".format(
                thr, inp, loop)
            out = check_output(cmd, shell=True).decode("ascii")
            m = re.search("time: (.*)", out)
            if m is not None:
                time = m.group(1)
                csv.append(time)

        csvs.append(csv)
        sleep(0.5)

header = ["microseconds"] + [str(x) for x in THREADS]

print("\n")
print(", ".join(header))
for csv in csvs:
    print (", ".join(csv))



#!/usr/bin/env python3
import random
import os

K = 1024

INPUTS = {
    "1k.txt": 1*K,
    "8k.txt": 8*K,
    "16k.txt": 16*K,
}

try:
    os.mkdir("tests")
except:
    pass

for name, sz in INPUTS.items():
    with open(os.path.join("tests", name), 'w') as f:
        f.write("{}\n".format(sz))
        n = sz
        while n > 0:
            gen = min(n, 64*K)
            ar = [str(random.randint(0, 100000)) for _ in range(gen)]
            f.write("\n".join(ar))
            n -= gen

    with open(os.path.join("tests", "seq_64_test.txt"), 'w') as f:
        f.write("64\n")
        for i in range(64):
            f.write("{}\n".format(i))

    